## Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
## Authors: J. Burgalat
## 2016-2024

# global config
include(../config.pri)

TARGET = ADMin2
TEMPLATE = app
VERSION = 2.3.1

CONFIG += c++14

DEFINES += APP_VER=\\\"$$VERSION\\\"
QT += core gui widgets printsupport concurrent network xml xmlpatterns

#should be define to a valid runtime licence token otherwise some functionalities should not work !
# https://developers.arcgis.com/qt/license-and-deployment/license-levels-and-capabilities/
DEFINES += ARCGIS_RT_LIC=\\\"\\\"

win32:QT += winextras

include(../common/common.pri)

include(../interfaces/interfaces.pri)

include (fit/fit.pri)
include (plotting/plotting.pri)
include (wifi/wifi.pri)
include (battery/battery.pri)
include (QtWaitingSpinner/qtwaitingspinner.pri)


#cutlogger
include(../CUTELOGGER2/cl2-embedded.pri)

# Some options (feature defined a compilation time):
#
# O_FULLSCREEN : Add basic support for Fullscreen mode
# O_HELP : Add action for help manual display.

# scenario selector is on map widget instead on mainwindow toolbar !
#DEFINES += SCN_SEL_ON_MAP

DEFINES += O_FULLSCREEN
DEFINES += O_HELP

CONFIG(debug,debug|release){
  DEFINES += DEBUG_BUILD
}

# Lock UI Password
DEFINES += WITH_PWD_LOCK

contains( DEFINES, WITH_PWD_LOCK ) {
    DEFINES += LOCK_PWD=\\\"ausea@gsma\\\"
}

ARCGIS_RUNTIME_VERSION = 100.15.0
include($$PWD/arcgisruntime.pri)

# Source files

INCLUDEPATH += sources

SOURCES += \
    sources/arcgisaccountwidget.cpp \
    sources/layoutselector.cpp \
    sources/main.cpp \
    sources/aspectratiopixmaplabel.cpp \
    sources/basemapselector.cpp \
    sources/admconfig.cpp \
    sources/basertplotwidget.cpp \
    sources/clickablelabel.cpp \
    sources/clockwidget.cpp \
    sources/colorindicator.cpp \
    sources/commwidget.cpp \
    sources/configwidget.cpp \
    sources/cpumemwidget.cpp \
    sources/dataitem.cpp \
    sources/dataloader.cpp \
    sources/dataloaderdialog.cpp \
    sources/datamanager.cpp \
    sources/datarange.cpp \
    sources/filenamewidget.cpp \
    sources/flightmodel.cpp \
    sources/flightwidget.cpp \
    sources/globals.cpp \
    sources/gpsstatuswidget.cpp \
    sources/gpswidget.cpp \
    sources/indicatorchoicedialog.cpp \
    sources/indicatormodel.cpp \
    sources/indicators.cpp \
    sources/indicatorseditor.cpp \
    sources/indicatorswidget.cpp \
    sources/indicatorwidget.cpp \
    sources/inversionstatuswidget.cpp \
    sources/itemchoicedialog.cpp \
    sources/itemmapper.cpp \
    sources/itemmodel.cpp \
    sources/itemseditor.cpp \
    sources/layoutmanager.cpp \
    sources/layoutmanagerdialog.cpp \
    sources/layoutnamedialog.cpp \
    sources/loginview.cpp \
    sources/mainwindow.cpp \
    sources/helpers.cpp \
    sources/mapitemeditor.cpp \
    sources/mapwidget.cpp \
    sources/mediacontrolwidget.cpp \
    sources/movingavg.cpp \
    sources/networkconfig.cpp \
    sources/prm_utils.cpp \
    sources/rtplotwidget.cpp \
    sources/scenario.cpp \
    sources/scenarioeditor.cpp \
    sources/scenarioselector.cpp \
    sources/scenariosmodel.cpp \
    sources/scenariowidget.cpp \
    sources/screenshotmanager.cpp \
    sources/audpsocket.cpp \
    sources/abstractudpsocket.cpp \
    sources/scenarioseditor.cpp \
    sources/settings/warningspage.cpp \
    sources/timestampwidget.cpp \
    sources/directorywidget.cpp \
    sources/udpstatuswidget.cpp \
    sources/valuelineedit.cpp \
    sources/wlanwidget.cpp \
    sources/xmlutils.cpp

HEADERS  += \
    sources/arcgisaccountwidget.hpp \
    sources/aspectratiopixmaplabel.hpp \
    sources/basemapselector.hpp \
    sources/admconfig.hpp \
    sources/arcgis.hpp \
    sources/basertplotwidget.hpp \
    sources/borderanimation.hpp \
    sources/cfg_versions.hpp \
    sources/clickablelabel.hpp \
    sources/clockwidget.hpp \
    sources/colorindicator.hpp \
    sources/commwidget.hpp \
    sources/configwidget.hpp \
    sources/cpumemwidget.hpp \
    sources/dataitem.hpp \
    sources/dataloader.hpp \
    sources/dataloaderdialog.hpp \
    sources/datamanager.hpp \
    sources/datarange.hpp \
    sources/dndviewstyle.hpp \
    sources/filenamewidget.hpp \
    sources/flightmodel.hpp \
    sources/flightwidget.hpp \
    sources/globals.hpp \
    sources/gpsstatuswidget.hpp \
    sources/gpswidget.hpp \
    sources/indicatorchoicedialog.hpp \
    sources/indicatormodel.hpp \
    sources/indicators.hpp \
    sources/indicatorseditor.hpp \
    sources/indicatorswidget.hpp \
    sources/indicatorwidget.hpp \
    sources/inversionstatuswidget.hpp \
    sources/itemchoicedialog.hpp \
    sources/itemmapper.hpp \
    sources/itemmodel.hpp \
    sources/itemseditor.hpp \
    sources/layoutmanager.hpp \
    sources/layoutmanagerdialog.hpp \
    sources/layoutnamedialog.hpp \
    sources/layoutselector.hpp \
    sources/lineedit.hpp \
    sources/listview.hpp \
    sources/loginview.hpp \
    sources/mainwindow.hpp \
    sources/helpers.hpp \
    sources/mapitemeditor.hpp \
    sources/mapwidget.hpp \
    sources/mediacontrolwidget.hpp \
    sources/movingavg.hpp \
    sources/mymessagebox.hpp \
    sources/networkconfig.hpp \
    sources/prm_utils.hpp \
    sources/rtplotwidget.hpp \
    sources/scenario.hpp \
    sources/scenarioeditor.hpp \
    sources/scenarioselector.hpp \
    sources/scenariosmodel.hpp \
    sources/scenariowidget.hpp \
    sources/screenshotmanager.hpp \
    sources/audpsocket.hpp \
    sources/abstractudpsocket.hpp \
    sources/scenarioseditor.hpp \
    sources/settings/warningspage.hpp \
    sources/tableview.hpp \
    sources/timestampwidget.hpp \
    sources/directorywidget.hpp \
    sources/udpstatuswidget.hpp \
    sources/valuelineedit.hpp \
    sources/wlanwidget.hpp \
    sources/xmlutils.hpp

# delegates
INCLUDEPATH += sources/delegates

SOURCES += \
    sources/delegates/comboboxunitsdelegate.cpp \
    sources/delegates/booleandelegate.cpp \
    sources/delegates/lineeditdelegate.cpp \
    sources/delegates/nameeditdelegate.cpp \
    sources/delegates/valuelineeditdelegate.cpp

HEADERS += \
    sources/delegates/comboboxunitsdelegate.hpp \
    sources/delegates/booleandelegate.hpp \
    sources/delegates/lineeditdelegate.hpp \
    sources/delegates/nameeditdelegate.hpp \
    sources/delegates/valuelineeditdelegate.hpp \
    sources/delegates/delegates.hpp

#settings
INCLUDEPATH += sources/settings

SOURCES += \
    sources/settings/graphpage.cpp \
    sources/settings/mappage.cpp \
    sources/settings/settingsdialog.cpp \
    sources/settings/generalpage.cpp \
    sources/settings/monitoringpage.cpp \
    sources/settings/storagepage.cpp \
    sources/settings/colorchooserlabel.cpp

HEADERS += sources/settings/basepage.hpp \
    sources/settings/graphpage.hpp \
    sources/settings/mappage.hpp \
    sources/settings/monitoringpage.hpp \
    sources/settings/settingsdialog.hpp \
    sources/settings/generalpage.hpp \
    sources/settings/storagepage.hpp \
    sources/settings/colorchooserlabel.hpp

DISTFILES += \
    readme.md \
    NOTES.txt \
    TODO \
    changelog.txt

##############
## Resources #
##############

RESOURCES += resources/admin.qrc
# Icon stuff: only for windows
win32{
  RC_FILE = resources/admin.rc
  ICON = resources/images/app.ico
}

TRANSLATIONS = resources/app_fr.ts
