// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef BATTERYSTATUSWIDGET_H
#define BATTERYSTATUSWIDGET_H

#include "batterystatusworker.hpp"
#include <QIcon>
#include <QLabel>
#include <QWidget>
#include <QtCore>

class BatteryStatusWidget : public QWidget {
    Q_OBJECT
  public:
    explicit BatteryStatusWidget(QWidget *parent = nullptr);
    virtual ~BatteryStatusWidget();
    void showPercent(bool show, bool update = true);
    void showLifeTime(bool show, bool update = true);

  protected:
    virtual void hideEvent(QHideEvent *event);
    virtual void showEvent(QShowEvent *event);

  private slots:
    void onStatusUpdated(BatteryStatusWorker::Status status, int percent, int lifetime);

  private:
    void updateWidget();

  private:
    bool mShowLifetime;
    bool mShowPercent;
    BatteryStatusWorker::Status mStatus;
    int mPercent;
    int mLifetime;

    QThread *mThread;
    BatteryStatusWorker *mWorker;
    static const QSize iconSize;

    QPixmap mPixmapCharged;
    QPixmap mPixmapCharging;
    QPixmap mPixmapUnknown;
    QPixmap mPixmapOnBatteryLow;
    QPixmap mPixmapOnBatteryVeryLow;
    QPixmap mPixmapOnBatteryMedium;
    QPixmap mPixmapOnBatteryHigh;
    QPixmap mPixmapNoBattery;
    QLabel *mLblIcon;
    QLabel *mLblInfos;
};

#endif // BATTERYSTATUSWIDGET_H
