// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef FITPLOTWIDGET_HPP
#define FITPLOTWIDGET_HPP

#include "globals.hpp"

#include <QWidget>

class FitPlot;

class FitPlotWidget : public QWidget {
    Q_OBJECT
  public:
    explicit FitPlotWidget(QWidget *parent = nullptr);
    virtual ~FitPlotWidget();
    virtual QSize sizeHint() const override;
    void translateUI();

    void setFitReport(const FitReport &report);
    void clearPlots();
  public slots:
    void setAutoRescale(bool enabled);

  private slots:
    void onPlotContextMenuRequested(const QPoint &pos);

  private:
    void setupActions();
    FitPlot *mPlot; ///< Plot widget.

    QAction *mActionAutoRescale; ///< Auto rescale action.
    QAction *mActionYRescale;    ///< Y-axis Rescale action.
    QAction *mActionXRescale;    ///< X-axis Rescale action.
    QAction *mActionRescale;     ///< all axes Rescale action.

    bool mAutoRescale; ///< Auto rescale control flag.

    QSharedPointer<QCPGraphDataContainer> mRampData;       ///< Ramp data.
    QSharedPointer<QCPGraphDataContainer> mRawSpectraData; ///< Raw spectra data (scaled with baseline).
    QSharedPointer<QCPGraphDataContainer> mFitSpectraData; ///< Fit spectra data
    QSharedPointer<QCPGraphDataContainer> mResidualData;   ///< Residual data.
};

#endif // FITPLOTWIDGET_HPP
