// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef ADMCONFIG_HPP
#define ADMCONFIG_HPP

#include "globals.hpp"
#include "networkconfig.hpp"
#include <QtXml>

class AdmConfig {
  public:
    AdmConfig();
    AdmConfig(const AdmConfig &other);
    ~AdmConfig();

    AdmConfig &operator=(const AdmConfig &other);

    bool isValid() const;
    bool parse(const QString &xmlPath, QStringList *errors = nullptr);
    bool parseContent(const QString &content, const QString directory = QString(), QStringList *errors = nullptr);
    bool validate(const QString &xmlPath, QStringList *errors = nullptr);
    bool validateContent(const QString &xmlContent, QStringList *errors = nullptr);

    QByteArray toXML() const;
    void clear();
    const QString &name() const;
    int cfgVersion() const;
    QByteArray xsdSchema() const;
    const QString &directory() const;

    QString scenarioFilePath() const;
    QString indicatorFilePath() const;

    QString fitFilePath() const;
    QString keymapFilePath() const;

    int instrumentNumber() const;
    int firmwareVersion() const;
    int laserWarmup() const;
    const ABlock &descriptor() const;
    const NetworkConfig &networkConfig() const;

  private:
    QByteArray mXsdSchema;        ///< XML validation schema.
    bool mValid;                  ///< Configuration validity flag.
    QString mDirectory;           ///< Directory of the related configuration file.
    QString mName;                ///< Configuration name.
    int mCfgVersion;              ///< Config file version.
    int mNumInstrument;           ///< Instrument number of the associated descriptor.
    int mNumVersion;              ///< Firmware version number of the associated descriptor.
    int mLaserWarmup;             ///< Laser warmup time in seconds.
    NetworkConfig mNetworkConfig; ///< UDP & Wifi configuration.

    QString mDescriptorPath; ///< Path of the descriptor file.
    QString mKeymapPath;     ///< Path of keymap file.
    QString mFitPath;        ///< Path of fit configuration file.
    QString mIndicatorPath;  ///< Path of indicator configuration file.
    QString mScenarioPath;   ///< Path of the scenarios file.

    ABlock mRawDescriptor; ///< AMULSE block descriptor.

    bool setupDescriptor(QStringList *errors);
    bool readNetwork(QDomNode parentNode, QStringList *errors);
    QString networkToXML() const;
    QString processPath(QString filePath);
};
#endif // ADMCONFIG_HPP
