// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "aspectratiopixmaplabel.hpp"

#include <QDebug>

static const QByteArray noImageB64 =
    QByteArray::fromBase64("iVBORw0KGgoAAAANSUhEUgAAAoAAAAHgAQMAAAAPH06nAAAABlBMVEX///"
                           "8AAABVwtN+"
                           "AAAACXBIWXMAAA7EAAAOxAGVKw4bAAAAPUlEQVR4nO3BAQ0AAADCoPdPbQ43oAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"
                           "AAAAAAAAAAAAAAAAAAADgzwCX4AAB9Dl2RwAAAABJRU5ErkJggg==");
/// @brief Constructor.
AspectRatioPixmapLabel::AspectRatioPixmapLabel(QWidget *parent) : QLabel(parent) {
    noPixmap = QPixmap::fromImage(QImage::fromData(noImageB64, "PNG"));
    setPixmap(noPixmap);
    setScaledContents(true);
    QSizePolicy policy(QSizePolicy::Maximum, QSizePolicy::Maximum);
    policy.setHeightForWidth(true);
    setSizePolicy(policy);
    setMinimumSize(320,240);
}

/// @rief Set new pixmap in the label.
void AspectRatioPixmapLabel::setPixmap(const QPixmap &pixmap) {
    mPixOrigSize = pixmap.size();
    QLabel::setPixmap(pixmap);
}

void AspectRatioPixmapLabel::resetPixmap() { setPixmap(noPixmap); }

/// @brief Compute the height of the label for the given width.
int AspectRatioPixmapLabel::heightForWidth(int width) const {
    QPixmap pix = pixmap(Qt::ReturnByValue);
    qDebug() << Q_FUNC_INFO << pix.width() << mPixOrigSize.width();
    if (width > pix.width()) {
        return pix.height();
    } else {
        return ((qreal)pix.height() * width) / pix.width();
    }
}

/// @brief Check whether or not the label has a preferred height for width.
bool AspectRatioPixmapLabel::hasHeightForWidth() { return true; }

/// @brief Get the size hint for the label.
QSize AspectRatioPixmapLabel::sizeHint() const { return pixmap(Qt::ReturnByValue).size(); }

/// @brief Ge tthe minimum size hint of the label.
QSize AspectRatioPixmapLabel::minimumSizeHint() const { return QSize(0, 0); }
