// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

/*
 * Copyright (C) 2016-2019  Jeremie Burgalat (jeremie.burgalat at univ-reims dot fr)
 *
 * This file is part of ATLAS.
 *
 * ATLAS is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with ATLAS. If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * @file borderanimation.hpp
 * @brief BorderAnimation class declarations file.
 * @author J. Burgalat.
 * @date 2016
 */

#ifndef BORDERANIMATION_HPP
#define BORDERANIMATION_HPP

#include <QVariantAnimation>
#include <QWidget>

#include <QDebug>

/// @brief Generate an animation on widget border.
/// @details
/// This animation generates a blinking red border on the target widget.
/// It is used in the application to warn user about missing/wrong data in
/// input fields
class BorderAnimation : public QVariantAnimation {
    Q_OBJECT
  public:
    BorderAnimation(QWidget *target, QObject *parent = nullptr)
        : QVariantAnimation(parent)
        , target(target) {
        setDuration(500);
        setStartValue(0);
        setKeyValueAt(0.025, 255);
        setKeyValueAt(0.325, 255);
        setKeyValueAt(0.35, 0);
        setKeyValueAt(0.65, 0);
        setKeyValueAt(0.675, 255);
        setKeyValueAt(0.975, 255);
        setEndValue(0);
        target->setStyleSheet(QString("border-color: rgba(0, 0, 0, 0)"));
    }

    virtual ~BorderAnimation() override {}

  protected:
    /**
     * @brief Update current value of the border property.
     * @param value New value to set in the property.
     * @details The method updates the stylesheet of the target widget.
     * It sets a red color with varying alpha (given by <i>value</i> argument).
     */
    virtual void updateCurrentValue(const QVariant &value) override {
        int alpha = value.toInt();
        if (alpha == 0) {
            target->setStyleSheet("");
        } else {
            target->setStyleSheet(QString("background-color: rgba(255, 0, 0, 100)"));
        }
    }

  private:
    QWidget *target;
};

#endif // BORDERANIMATION_HPP
