// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "clockwidget.hpp"
#include <QDateTime>
#include <QTimer>

/// @brief Constructor.
ClockWidget::ClockWidget(QWidget *parent) : QLabel{parent} {
    mDate = true;
    mSeconds = true;
    mUTC = false;
    buildFormat();
    updateTime();
    mTimer = new QTimer(this);
    mTimer->setInterval(1000);
    mTimer->setTimerType(Qt::PreciseTimer);
    QObject::connect(mTimer, &QTimer::timeout, this, &ClockWidget::updateTime);
}

/// @brief Show date in clock.
void ClockWidget::showDate(bool show) {
    mDate = show;
    buildFormat();
}
/// @brief Show seconds in clock.
void ClockWidget::showSeconds(bool show) {
    mSeconds = show;
    buildFormat();
}

/// @brief Use UTC time instead of local time.
void ClockWidget::setUTC(bool enable) {
    mUTC = enable;
    buildFormat();
}

/// @brief Build clock format.
void ClockWidget::buildFormat() {
    mFormat = QString("%1HH:mm%3%4").arg(mDate ? "dd/MM/yyyy " : "", mSeconds ? ":ss" : "", mUTC ? " UTC" : "");
}
/// @brief Update displayed time.
void ClockWidget::updateTime() {
    QDateTime time = mUTC ? QDateTime::currentDateTimeUtc() : QDateTime::currentDateTime();
    setText(time.toString(mFormat));
}

/// @brief Stop update time on hide.
void ClockWidget::hideEvent(QHideEvent *event) {
    mTimer->stop();
    QLabel::hideEvent(event);
}

/// @brief Start update time on show.
void ClockWidget::showEvent(QShowEvent *event) {
    mTimer->start();
    QLabel::showEvent(event);
}
