// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "commwidget.hpp"
#include "colorindicator.hpp"
#include "gpsstatuswidget.hpp"
#include "udpstatuswidget.hpp"
#include "wlanwidget.hpp"

CommWidget::CommWidget(QWidget *parent) : QWidget(parent) {

    mWLANWidget = new WLANWidget(this);
    mUDPWidget = new UDPStatusWidget(this);
    mGPSWidget = new GPSStatusWidget(this);
    mWLANWidget->layout()->setContentsMargins(0, 0, 0, 0);
    mUDPWidget->layout()->setContentsMargins(0, 0, 0, 0);
    mGPSWidget->layout()->setContentsMargins(0, 0, 0, 0);
    QVBoxLayout *layout = new QVBoxLayout(this);
    layout->addWidget(mWLANWidget);
    layout->addWidget(mUDPWidget);
    layout->addWidget(mGPSWidget);
    layout->addStretch(1);
}

///**
// * @brief Try to monitor given SSID.
// * @param ssid SSID of the wireless network to monitor.
// * @sa WLANWidget::monitorSSID
// */
// void CommWidget::monitorSSID(const QString &ssid) {
//    mWLANWidget->monitorSSID(ssid);
//}

/// @brief Translate widgets texts.
void CommWidget::translateUI() {
    setWindowTitle(tr("Communications"));
    mUDPWidget->translateUI();
    mGPSWidget->translateUI();
}

/// @brief Reset widget to display defaults.
void CommWidget::reset() {
    mUDPWidget->reset();
    mWLANWidget->reset();
}

/// @brief Get a pointer to the UDP status widget child.
QPointer<WLANWidget> CommWidget::wlanWidget() const { return mWLANWidget; }

/// @brief Get a pointer to the UDP status widget child.
QPointer<UDPStatusWidget> CommWidget::udpWidget() const { return mUDPWidget; }

/// @brief Get a pointer to the GPS status widget child.
QPointer<GPSStatusWidget> CommWidget::gpsWidget() const { return mGPSWidget; }
