// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "configwidget.hpp"

ConfigWidget::ConfigWidget(QWidget *parent) : QGroupBox(parent) {
    mLblNameDescr = new QLabel(this);
    mLblDescrDescr = new QLabel(this);
    mLblInvDescr = new QLabel(this);

    mLblName = new QLabel(this);
    mLblDescr = new QLabel(this);
    mLblInv = new QLabel(this);

    QFormLayout *formLayout = new QFormLayout(this);
    formLayout->addRow(mLblNameDescr, mLblName);
    formLayout->addRow(mLblDescrDescr, mLblDescr);
    formLayout->addRow(mLblInvDescr, mLblInv);
    updateConfig(AdmConfig());
}

/// @brief Update configuration groupbaox displayed data.
void ConfigWidget::updateConfig(const AdmConfig &config, FitConfig *fitConfig) {
    QString msg = QString("<font color='%1'>%2</font>");
    if (config.isValid()) {
        mLblName->setText(msg.arg("black", config.name()));
        int numIns = config.instrumentNumber(), fver = config.firmwareVersion();
        mLblDescr->setText(msg.arg("green", QString("I:%1, V:%2").arg(numIns).arg(fver)));
        if (fitConfig)
            mLblInv->setText(fitConfig->isValid() ? msg.arg("green", tr("Valid")) : msg.arg("red", tr("Invalid")));
    } else {
        mLblName->setText(msg.arg("orange", tr("None")));
        mLblDescr->setText(msg.arg("orange", tr("None")));
        mLblInv->setText(msg.arg("orange", tr("None")));
    }
}

/// @brief Translate texts.
void ConfigWidget::translateUI() {
    setTitle(tr("Configuration"));
    mLblNameDescr->setText(tr("Name"));
    mLblDescrDescr->setText(tr("Descriptor"));
    mLblInvDescr->setText(tr("Inversion"));
}
