// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef CPUMEMWIDGET_HPP
#define CPUMEMWIDGET_HPP

#include "globals.hpp"

class CpuMemWidget : public QWidget {
    Q_OBJECT
  public:
    explicit CpuMemWidget(QWidget *parent = nullptr);
    void setTimeRate(int timeRate);
    virtual void translateUI();
    virtual QSize sizeHint() const override;

    bool cpuVisible() const;
    void setCpuVisible(bool cpuVisible);

    bool ramVisible() const;
    void setRamVisible(bool ramVisible);

    bool rioVisible() const;
    void setRioVisible(bool rioVisible);

    bool wioVisible() const;
    void setWioVisible(bool wioVisible);

  protected:
    virtual void hideEvent(QHideEvent *event) override;
    virtual void showEvent(QShowEvent *event) override;

  private slots:
    void onTimeout();

  protected:
    QFormLayout *mLayout;

  private:
    bool mCpuVisible;
    bool mRamVisible;
    bool mRioVisible;
    bool mWioVisible;

    QLabel *mLblCPUd;
    QLabel *mLblRAMd;
    QLabel *mLblRIOd;
    QLabel *mLblWIOd;
    QLabel *mLblCPU;
    QLabel *mLblRAM;
    QLabel *mLblRIO;
    QLabel *mLblWIO;
    QTimer *mSysTimer;
    int mTimeRate;
    int mTotalRAM;
    int mFmt;
};

#endif // CPUMEMWIDGET_HPP
