// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef DATALOADER_HPP
#define DATALOADER_HPP

#include "globals.hpp"

class AMDataset;
class ItemMapper;

class DPP {
  public:
    enum Process { TRUNCATE, DECIMATE, RESAMPLE, NOTHING };
    DPP() : process(NOTHING), keepPoints(0), decimationStep(0), resampleStep(0){}
    Process process;
    int keepPoints;
    int decimationStep;
    double resampleStep;
};

/// @brief Load files into dataset.
class DataLoader : public QObject {
    Q_OBJECT
  public:
    DataLoader(DPP parameters, const QVector<long> &indexes, const ItemMapper *itemMapper, const AMDataset *dataset,
               QObject *parent = nullptr);

    virtual ~DataLoader();
    bool canceled() const;
    bool isRunning() const;
    int progressCount() const;

signals:
    /**
     * @brief Emitted when the data is ready.
     * @param data The replay data.
     * @details
     * The pointer is not owned by this loader. It user responsibility to delete it if needed.
     */
    void dataReady(ReplayData *data);
    /**
     * @brief Emitted when job is finished whatever the status is.
     * @param aborted True if job has been aborted, false otherwise.
     */
    void finished(bool aborted = false);
    /// @brief Emitted whenever a processing message is sent by the loader.
    void infoMessage(const QString msg);
    /// @brief Emitted whenever a step message is sent by the loader.
    void stepMessage(const QString msg);

  public slots:
    void process();
    void cancel();

  private:
    DPP mParams;
    QVector<long> mValidIndexes;
    const ItemMapper *mItemMapper;
    const AMDataset *mDataset;
    mutable QMutex mDataMutex;
    bool mIsRunning;
    bool mCancel;
};

#endif // DATALOADER_HPP
