// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef DATASETLOADERDIALOG_HPP
#define DATASETLOADERDIALOG_HPP

#include "globals.hpp"

class ItemMapper;
class DataLoader;
class FileLoader;
class AMDataset;

class DataLoaderDialog : public QDialog {
    Q_OBJECT
  public:
    explicit DataLoaderDialog(const QStringList &files, const ItemMapper *mapper, QWidget *parent = nullptr,
                              Qt::WindowFlags flags = Qt::WindowFlags());
    virtual ~DataLoaderDialog();
    virtual QSize sizeHint() const override;
    ReplayData *data() const;

  protected:
    virtual void showEvent(QShowEvent *event) override;

  protected:
    virtual void keyPressEvent(QKeyEvent *e) override;

  private:
    void loadFiles();
    void checkDataset();

  private slots:
    void onFileProgressChanged(int index);
    void onFileLoadingFinished();
    void onDatasetLoaded(AMDataset *dataset);

    void processData();
    void onDataReady(ReplayData *replayData);
    void onDataProcessingFinished();

    void cancelAndQuit();

  private:
    int mMaxPoints;
    QStringList mFiles;
    QVector<long> mBaseIndexes;
    const ItemMapper *mItemMapper = nullptr;
    AMDataset *mDataset = nullptr;

    QThread *mLoaderThread = nullptr;
    FileLoader *mFileLoader = nullptr;
    DataLoader *mDataLoader = nullptr;
    ReplayData *mReplayData;

    QGroupBox *mGbxProgress;
    QLabel *mLblProgressStep = nullptr;
    QLabel *mLblProgressInfo = nullptr;

    QGroupBox *mGbxDatasetInfos;
    QLabel *mLblDINb;
    QLabel *mLblStartDate;
    QLabel *mLblEndDate;
    QLabel *mLblTimestep;

    QGroupBox *mGbxOperations;
    QRadioButton *mRdbNothing;
    QRadioButton *mRdbDecimate;
    QSpinBox *mSpbDecimate;
    QRadioButton *mRdbDownSample;
    QDoubleSpinBox *mSpbDownSample;
    QRadioButton *mRdbTruncate;
    QSpinBox *mSpbTruncate;

    QGroupBox *mGbxReplayInfos;
    QLabel *mLblRINb;

    QPushButton *mOkButton = nullptr;
    QPushButton *mCancelButton = nullptr;
};

#endif // DATASETLOADERDIALOG_HPP
