// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "booleandelegate.hpp"

/// @brief Constructor.
BooleanDelegate::BooleanDelegate(QObject *parent, bool defaultValue)
    : QStyledItemDelegate(parent), mDefaultvalue(defaultValue) {}

/// @brief Paint the delegate.
void BooleanDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const {
    QVariant value = index.data(Qt::EditRole);

    bool boolVal = value.isValid() ? value.toBool() : mDefaultvalue;
    QStyle *style = QApplication::style();
    QRect checkBoxRect = style->subElementRect(QStyle::SE_CheckBoxIndicator, &option);
    int chkWidth = checkBoxRect.width();
    int chkHeight = checkBoxRect.height();

    int centerX = option.rect.left() + qMax(option.rect.width() / 2 - chkWidth / 2, 0);
    int centerY = option.rect.top() + qMax(option.rect.height() / 2 - chkHeight / 2, 0);
    QStyleOptionViewItem modifiedOption(option);

    modifiedOption.rect.moveTo(centerX, centerY);
    modifiedOption.rect.setSize(QSize(chkWidth, chkHeight));

    modifiedOption.text = "";
    if (boolVal) {
        modifiedOption.state |= QStyle::State_On;
    }

    style->drawPrimitive(QStyle::PE_IndicatorItemViewItemCheck, &modifiedOption, painter);
}

/// @brief Change state of the checkbox.
bool BooleanDelegate::editorEvent(QEvent *event, QAbstractItemModel *model, const QStyleOptionViewItem &option,
                                  const QModelIndex &index) {
    bool isChecked = model->data(index, Qt::EditRole).toBool();
    bool repaint_cell = false;

    QMouseEvent *e = static_cast<QMouseEvent *>(event);

    // We need to check if the mouse pointer is hovering within
    // the checkbox indicator area of the table cell
    QStyleOptionButton checkbox_indicator;
    checkbox_indicator.rect = QApplication::style()->subElementRect(QStyle::SE_CheckBoxIndicator, &checkbox_indicator, NULL);
    const int x = option.rect.center().x() - checkbox_indicator.rect.width() / 2;
    const int y = option.rect.center().y() - checkbox_indicator.rect.height() / 2;
    checkbox_indicator.rect.moveTo(x, y);
    if (checkbox_indicator.rect.contains(e->pos())) {
        repaint_cell = true;
        // Check if the user has clicked in this area
        if (e->type() == QEvent::MouseButtonRelease && e->button() == Qt::LeftButton) {
            model->setData(index, !isChecked, Qt::EditRole);
        }
    }
    return repaint_cell;
}
