// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "directorywidget.hpp"

DirectoryWidget::DirectoryWidget(QWidget *parent) : QWidget(parent) {

    mEditor = new QLineEdit(this);
    QCompleter *completer = new QCompleter(mEditor);

    //QDirModel *model = new QDirModel(completer);
    QFileSystemModel *model = new QFileSystemModel(completer);
    model->setFilter(QDir::Dirs | QDir::AllDirs);
    completer->setModel(model);
    mEditor->setCompleter(completer);

    mBtnBrowse = new QToolButton(this);
    mBtnBrowse->setIcon(QIcon::fromTheme("folder-open"));
    QHBoxLayout *layout = new QHBoxLayout(this);
    layout->setContentsMargins(0, 0, 0, 0);

    QObject::connect(mBtnBrowse, &QToolButton::clicked, this, &DirectoryWidget::browseFolder);

    layout->addWidget(mEditor);
    layout->addWidget(mBtnBrowse, 0, Qt::AlignRight);
}

/**
 * @brief Open a file dialog to pick up directory.
 * @details
 * The method is called when the directory browsing button is clicked.It launches a file dialog,
 * get the selected directory and save its path in the LineEdit.
 */
void DirectoryWidget::browseFolder() {
    QSettings settings;
    QString idir = settings.value("storage/datadir",
                                  QStandardPaths::standardLocations(QStandardPaths::DocumentsLocation).first()).toString();
    QString fdir = QFileDialog::getExistingDirectory(this, tr("Select a directory"), idir);
    if (!fdir.isEmpty()) {
        settings.setValue("storage/datadir", fdir);
        mEditor->setText(fdir);
    }
}

/// @brief Get the current directory display in the line edit.
QString DirectoryWidget::directory() { return mEditor->text(); }

/// @brief Set a directory to display in the line edit.
void DirectoryWidget::setDirectory(const QString &directory) { mEditor->setText(directory); }

QSize DirectoryWidget::sizeHint() const { return QSize(200, 32); }
