// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef FLIGHTMANAGER_HPP
#define FLIGHTMANAGER_HPP

#include "globals.hpp"

class FlightModel : public QAbstractTableModel {

    Q_OBJECT

  public:
    FlightModel(QObject *parent = nullptr);
    virtual ~FlightModel();

    void resetFlights();
    int flightCount() const;

    void checkAll(bool signalNeeded = true);
    void uncheckAll(bool signalNeeded = true);

    QVector<int> checkedFlights() const;
    QVector<int> unCheckedFlights() const;

    void addFlight(const QDateTime &startTime, const QDateTime &endTime, int itemCount, Qt::CheckState state = Qt::Checked);

    bool removeFlight(int index);

    virtual Qt::ItemFlags flags(const QModelIndex &index) const override;
    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const override;
    virtual int columnCount(const QModelIndex &parent) const override;

    virtual bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;

    QDateTime startTime(int index) const;
    QDateTime endTime(int index) const;
    int itemCount(int index) const;
    Qt::CheckState checkState(int index) const;

    void translateHeaders();

signals:
    /**
     * @brief Emitted whenever a flight state changes.
     * @param index Index of the flight (i.e. row number) in the model.
     * @param checked True if the flight is now checked, false otherwise.
     */
    void stateChanged(int index, bool checked);

  private:
    QStringList mHeaders;
    QVector<QDateTime> mStartTimes;
    QVector<QDateTime> mEndTimes;
    QVector<int> mItemCount;
    QVector<Qt::CheckState> mStates;
};

#endif // FLIGHTMANAGER_HPP
