// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "flightwidget.hpp"

FlightWidget::FlightWidget(QWidget *parent) : QWidget(parent) {

    QToolBar *toolBar = new QToolBar(this);
    addFlightAction = new QAction(QIcon::fromTheme("add"), "", this);
    delFlightAction = new QAction(QIcon::fromTheme("remove"), "", this);
    delFlightAction->setEnabled(false);
    checkAllAction = new QAction(QIcon::fromTheme("check-all"), "", this);
    uncheckAllAction = new QAction(QIcon::fromTheme("uncheck-all"), "", this);

    toolBar->addAction(addFlightAction);
    toolBar->addAction(delFlightAction);
    toolBar->addSeparator();
    QWidget *spacer = new QWidget(this);
    spacer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
    toolBar->addWidget(spacer);
    toolBar->addAction(checkAllAction);
    toolBar->addAction(uncheckAllAction);
    toolBar->setIconSize(TB_ICO_SIZE);
    tableView = new QTableView(this);
    QVBoxLayout *vlayout = new QVBoxLayout(this);
    vlayout->setContentsMargins(4, 4, 4, 4);
    vlayout->setSpacing(4);
    vlayout->setMenuBar(toolBar);
    vlayout->addWidget(tableView);
    tableView->setSelectionMode(QAbstractItemView::SingleSelection);
    tableView->setSelectionBehavior(QAbstractItemView::SelectRows);
    auto *header = tableView->horizontalHeader();
    header->setSectionResizeMode(QHeaderView::ResizeToContents);
    header->setStretchLastSection(true);
}

/**
 * @brief Enable/Disable buttons.
 * @param enable True to enable butons, false otherwise.
 */
void FlightWidget::setInteractionMode(bool enable) {
    delFlightAction->setEnabled(enable);
    addFlightAction->setEnabled(enable);
    checkAllAction->setEnabled(enable);
    uncheckAllAction->setEnabled(enable);
}

/// @brief Update the delete flight action internal data on tableview's selection changed.
void FlightWidget::onSelectionChanged(const QItemSelection &, const QItemSelection &) {
    auto selection = tableView->selectionModel()->selectedRows();
    int rowIndex = selection.size() ? selection.first().row() : -1;
    delFlightAction->setData(rowIndex);
    delFlightAction->setEnabled(rowIndex != -1);
}

/// @brief Translate widgets text.
void FlightWidget::translateUI() {
    setWindowTitle(tr("Flights"));
    addFlightAction->setText(tr("Add new flight"));
    delFlightAction->setText(tr("Delete selected flight"));
    checkAllAction->setText(tr("Check all flights"));
    uncheckAllAction->setText(tr("Uncheck all flights"));
    for (QAction *a : {addFlightAction, delFlightAction, checkAllAction, uncheckAllAction}) {
        a->setToolTip(a->text());
        a->setStatusTip(a->text());
    }
}
