// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

/*
 * Copyright (C) 2016-2018  Jeremie Burgalat (jeremie.burgalat at univ-reims dot fr)
 *
 * This file is part of ATLAS.
 *
 * ATLAS is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with ATLAS. If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * @file helpers.hpp
 * @brief Help strings methods declarations file.
 * @author J. Burgalat
 * @date 2016
 */

#ifndef HELPERS_HPP
#define HELPERS_HPP

#include <QString>
class QWidget;

enum HelpFlag {
    // GENERAL
    LANG,         // language change.
    FONT,         // font change
    SAVE_ON_FLY,  // Save config on the fly.
    SHOW_BATTERY, // Show battery usage.
    SHOW_CLOCK,   // show system clock.
    ART_SIGNIN,   // ArcGIS online sign-in
    // WARNINGS
    WARN_ARCGIS_SIGNIN, // warn for arcgis license.
    WARN_CONF,          // warn conf change.
    WARN_INV_CONF,      // warn invalid fit conf.
    WARN_EMPTY_SCN,     // warn empty scenarios.
    WARN_LMFAIL,        // warn bmap loading fail.
    WARN_REPLAY,        // warn replay switch.
    WARN_NOSD,          // warn when no SD card has been detected.
    // MONITORING
    NF_DELAY,          // new flight on delay
    NF_STRAP,          // new flight on strap
    MT_FIT,            // multithread fit.
    PROC_INTERNALS,    // Process internal parameters.
    PROC_NOGPS,        // Process block with invalid GPS data.
    MON_WIFI,          // Monitor WLAN connection.
    MAX_INPUT_FREQ,    // Maximum input frequency.
    MAX_INV_FREQ,      // Maximum inversion process frequency.
    FAST_CALCULATIONS, // Fast calculations.
    DISPLAY_FITS,      // Display fit plots.
    // MAP
    CENTER_LOC,    // Center map on sensor location
    SHOW_AT_LEAST, // show at least X secs.
    CS_ORIENT,     // Color scale orientation.
    CF_STYLE,      // Current flight marker style
    PF_STYLE,      // Previous flights marker style
    MV_STYLE,      // Missing value point style.
    HIDE_MV,       // Hide missing value point.
    // GRAPH
    HIDE_PTB, // hide plot widgets toolbar.
    HIDE_PXL, // hide plot widgets x-axis labels.
    ASPERIOD, // Auto-scrolling period.
    WTIME,    // window time setting.
    WOFFSET,  // window offset
    // STORAGE
    DDIR,    // data directory.
    LOGGING, // log on disk.
    LOG_LVL, // log level.
    DSAVE,   // save data on disk
    NFONF,   // new file on new flight.
};

QString getHelpMessage(HelpFlag flag, bool forSettings = false);
void setHelper(QWidget *widget, const QString &message);
void setHelper(QWidget *widget, HelpFlag flag);
#endif // HELPERS_HPP
