// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef LINEEDIT_HPP
#define LINEEDIT_HPP

#include <QLineEdit>
#include <QTimer>

class LineEdit : public QLineEdit {
    Q_OBJECT

    Q_PROPERTY(bool selectOnFocus MEMBER mSelectOnFocus READ selectOnFocus WRITE setSelectOnFocus NOTIFY selectOnFocusChanged)

  public:
    /// @brief Constructor.
    explicit LineEdit(const QString &contents, QWidget *parent = nullptr)
        : QLineEdit(contents, parent), mSelectOnFocus(false) {}
    /// @brief Constructor.
    explicit LineEdit(QWidget *parent = nullptr) : QLineEdit(parent), mSelectOnFocus(false) {}
    /// @brief Enable/Disable text selection on focus.
    void setSelectOnFocus(bool enabled) {
        mSelectOnFocus = enabled;
        emit selectOnFocusChanged(enabled);
    }
    /// @brief Check whether or not the line edit should select all text on focus.
    bool selectOnFocus() const { return mSelectOnFocus; }

  protected:
    /// @brief Manage text selection on focus.
    virtual void focusInEvent(QFocusEvent *event) override {
        QLineEdit::focusInEvent(event); // process the event.
        if (mSelectOnFocus)             // select all text using a timer if the property is enabled.
            QTimer::singleShot(1, this, &QLineEdit::selectAll);
    }

signals:
    void selectOnFocusChanged(bool);

  private:
    bool mSelectOnFocus;
};

#endif // LINEEDIT_HPP
