// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef LOGINVIEW_HPP
#define LOGINVIEW_HPP

#include "globals.hpp"

namespace Esri {
namespace ArcGISRuntime {
class Credential;
class Portal;
class AuthenticationChallenge;
enum class LoadStatus;
} // namespace ArcGISRuntime
} // namespace Esri

#include "TaskWatcher.h"

class LoginView : public QDialog {
    Q_OBJECT
  public:
    explicit LoginView(const QString customMessage = QString(), bool withCheckBox = false, QWidget *parent = nullptr);
    virtual ~LoginView();
    void translateUI();
    virtual QSize sizeHint() const override;
    void autoCloseOnSignIn(bool enable);

  protected:
    virtual void closeEvent(QCloseEvent *event) override;

  private slots:
    void tryLogin();

    void onPortalLoadStatusChanged(Esri::ArcGISRuntime::LoadStatus loadStatus);
    void cancelTask();

    void onAuthenticationChallenge(Esri::ArcGISRuntime::AuthenticationChallenge *challenge);

  private:
    bool mAutoClose;
    bool mCursorOverride;
    bool mIsFetching;
    QLabel *mLblInfos;
    QLineEdit *mLdtUserName;
    QLineEdit *mLdtPassword;
    QPushButton *mBtnConnect;
    QLabel *mLblResult;
    QCheckBox *mChbWarn;
    Esri::ArcGISRuntime::Credential *mCredentials;
    Esri::ArcGISRuntime::Portal *mPortal;
    QTimer mTimer;
};

#endif // LOGINVIEW_HPP
