// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "cpumemusage.hpp"
#include "globals.hpp"
#include "loginview.hpp"
#include "mainwindow.hpp"

#include <QApplication>
#ifdef Q_OS_WIN
#include <QtPlatformHeaders/QWindowsWindowFunctions>
#endif

int main(int argc, char *argv[]) {
    initMonitoring();

    QApplication app(argc, argv);
    // Setup Settings
    QCoreApplication::setOrganizationDomain("univ-reims.fr");
    QCoreApplication::setOrganizationName("urca-gsma");
    QCoreApplication::setApplicationName("ADMin2");
    QCoreApplication::setApplicationVersion(APP_VER);
    QSettings::setDefaultFormat(QSettings::IniFormat);
    app.setObjectName("Application");
    // app.setAttribute(Qt::AA_DontShowIconsInMenus);
    QSettings settings;
    bool firstTime = !(QFileInfo::exists(settings.fileName()) && settings.allKeys().size());
    QFont defaultFont(QApplication::font());
    defaultFont.setPointSizeF(qMax(8.0, defaultFont.pointSizeF()));
    app.setFont(settings.value("global/font", defaultFont).value<QFont>());
    QStringList themePaths = {":/adm2/icons"};
    themePaths.append(QIcon::themeSearchPaths());
    QIcon::setThemeSearchPaths(themePaths);
    QIcon::setThemeName("icons8");
    app.setQuitOnLastWindowClosed(false);

    // Customize splitter handles: make them more visible !
    app.setStyleSheet("QSplitter::handle,QMainWindow::separator{background: palette(dark);}");

    // check for first time application
    if (firstTime)
        setFactoryDefaults(QString());

    Esri::ArcGISRuntime::LicenseStatus status = initializeGlobals();
    if (status != Esri::ArcGISRuntime::LicenseStatus::Valid)
        LOG_WARNING(QCoreApplication::tr("Failed to load ArcGIS runtime license key..."));
    if (settings.value("warnings/no_arcgis_signin", true).toBool()) {
        LoginView *loginView = new LoginView("", true);
        loginView->setAttribute(Qt::WA_DeleteOnClose, true);
        loginView->exec();
    }

    QObject::connect(qApp, &QApplication::aboutToQuit, finalizeGlobals);

    // manage command-line argument :)
    QCommandLineParser parser;
    parser.setApplicationDescription("ADMin");
    parser.addHelpOption();
    parser.addVersionOption();
    parser.addPositionalArgument("configuration",
                                 QCoreApplication::translate("main", "Configuration file to open at startup."));
    parser.process(app);
    QString cfgPath = parser.positionalArguments().size() ? parser.positionalArguments().first() : "";

    if (!QFileInfo::exists(cfgPath))
        cfgPath = "";

    // Generate new main window
    MainWindow window(cfgPath, nullptr);
#ifdef Q_OS_WIN
    // hack for OpenGL fullscreen issue on Windows
    // see https://doc.qt.io/qt-5/windows-issues.html
    window.winId();
    QWindowsWindowFunctions::setHasBorderInFullScreen(window.windowHandle(), true);
#endif
    window.show();
    if (firstTime)
        window.centerToScreen();

    int result = app.exec();
    return result;
}
