// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef MEDIACONTROLWIDGET_HPP
#define MEDIACONTROLWIDGET_HPP

#include "globals.hpp"

class MediaControlWidget : public QWidget {
    Q_OBJECT
  public:
    explicit MediaControlWidget(QWidget *parent = nullptr);
    void setupControls(int frameCount);
    int frameStep() const;

    virtual QSize sizeHint() const override;
  public slots:
    void setFrameIndex(int value);
    void setState(ReplayState state);

signals:
    void loadRequest();
    void play();
    void stop();
    void pause();
    void goToEnd();
    void goToStart();
    void frameStepChanged(double rate);
    void frameIndexChanged(int index);
    void autoRepeat(bool enable);
  private slots:
    void playClicked();
    void updateFrameStep(int index);

  private:
    ReplayState mState;
    QToolButton *mLoadButton = nullptr;
    QToolButton *mPlayButton = nullptr;
    QToolButton *mStopButton = nullptr;
    QToolButton *mRepeatButton = nullptr;
    QToolButton *mGoToStartButton = nullptr;
    QToolButton *mGoToEndButton = nullptr;
    QSlider *mSlider = nullptr;
    QSpinBox *mSpinBox = nullptr;
    QComboBox *mCbxRate = nullptr;

  private:
    void resetControls();
};

#endif // MEDIACONTROLWIDGET_HPP
