// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef NETWORKCONFIG_HPP
#define NETWORKCONFIG_HPP

#include "globals.hpp"

/**
 * @brief The NetworkConfig class
 * @details
 * The class stores data about IP address and ports to listen to for UDP communication with the sensor.
 *
 * It may also store a SSID name that can be register in the NetworkIndicator class (such widget warns user on
 * connection/disconnection on the related network).
 */
class NetworkConfig {
  public:
    NetworkConfig(const QString &ipAddr = QString(), quint16 port = 0, const QString &ssid = QString());
    bool isValid() const;
    bool hasSSID() const;
    bool operator==(const NetworkConfig &other) const;
    bool operator!=(const NetworkConfig &other) const;
    bool comparable(const NetworkConfig &other) const;

    QString ipAddr;
    quint16 port;
    QString ssidName;
};

#endif // NETWORKCONFIG_HPP
