// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef RTPLOTWIDGET_HPP
#define RTPLOTWIDGET_HPP

#include "basertplotwidget.hpp"

class DataManager;
class DataItem;

/**
 * @brief The RtPlotWidget class
 * @details
 * The RtPlotWidget class inherits from BaseRtPlotWidget and is specialized so it can interact with a DataManager.
 *
 * Once a DataManger is set (RtPlotWidget::setDataManager), the widget can display data from one of its DataItem.
 */
class RtPlotWidget : public BaseRtPlotWidget {
    Q_OBJECT
  public:
    RtPlotWidget(int plotIndex, QWidget *parent = nullptr);

    virtual void refreshPlot() override;

    virtual void updateFromSettings() override;
    void updateFromItem(DataItem *item, GraphContainerVector graphContainers);
    void enableParameterSelection(bool enable);
    bool parameterSelectionEnabled() const;
    int index() const;
    DataItem *currentItem();

  protected slots:
    void setPositionText(double x, double y);

  private:
    int mIndex;
    DataItem *mCurrentItem;
    AParam mLastItemParam;
    bool mEnableParamSelection;
    bool mShowThreshold;
};

#endif // RTPLOTWIDGET_HPP
