// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef BASEPAGE_HPP
#define BASEPAGE_HPP

#include <QIcon>
#include <QWidget>

class BasePage : public QWidget {
  public:
    BasePage(QWidget *parent = nullptr) : QWidget(parent){}
    virtual void loadSettings() = 0;
    virtual void saveSettings() = 0;
    virtual void translateUI() = 0;
    const QString &pageTitle() const { return mPageTitle; }
    const QIcon &pageIcon() const { return mPageIcon; }

    /// @brief Save UI layout settings.
    /// @details The base implementation does nothing.
    virtual void saveUI(){};
    /// @brief Load UI layout settings.
    /// @details The base implementation does nothing.
    virtual void loadUI(){};

  protected:
    QString mPageTitle;
    QIcon mPageIcon;
};

#endif // BASEPAGE_HPP
