// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "colorchooserlabel.hpp"
#include <QColorDialog>

/// @brief Default constructor.
ColorChooserLabel::ColorChooserLabel(QWidget *parent) : ClickableLabel(parent) {
    setText(palette().windowText().color().name());
}

/**
 * @brief Constructor.
 * @param text Text to set in the label.
 * @param id Associated molecule identifier.
 * @param parent Parent widget.
 */
ColorChooserLabel::ColorChooserLabel(QColor color, QWidget *parent) : ClickableLabel(parent) { setText(color.name()); }

/// @brief Destructor.
ColorChooserLabel::~ColorChooserLabel() {}

/// @brief Get label text color
const QColor &ColorChooserLabel::color() const { return palette().windowText().color(); }

/// @brief Set label text color
void ColorChooserLabel::setColor(const QColor &color) {
    QPalette pal = this->palette();
    pal.setColor(foregroundRole(), color);
    setPalette(pal);
    setText(color.name());
}

/**
 * @brief Overrided mouseReleaseEvent.
 * @param event Mouse event.
 * @details
 * The method opens a color dialog to pick up a new color.
 */
void ColorChooserLabel::mouseReleaseEvent(QMouseEvent *event) {
    if (rect().contains(event->pos(), true)) {
        chooseGraphColor();
        emit colorChanged(color());
    }
    QLabel::mouseReleaseEvent(event);
}

/// @brief Set a new color from a color pick dialog.
void ColorChooserLabel::chooseGraphColor() {
    QColor col = getColor(color());
    setColor(col);
}

/// @brief Get color from QColorDialog.
QColor ColorChooserLabel::getColor(QColor initial) {
    QColor color = QColorDialog::getColor(initial, this, tr("Select a color"));
    if (color.isValid())
        return color;
    return initial;
}
