// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef TABLEVIEW_HPP
#define TABLEVIEW_HPP

#include <QMouseEvent>
#include <QTableView>
#include <QDebug>
/**
 * @brief The TableView class
 * @details
 * The class reimplements the mousePressEvent so a mouse press on an area that does not correspond to a valid index will
 * clear the selection (if any).
 */
class TableView : public QTableView {
    Q_OBJECT
  public:
    TableView(QWidget *parent = nullptr) : QTableView(parent) {}

  protected:
    virtual void mousePressEvent(QMouseEvent *event) override {
        if (event->button() == Qt::LeftButton) {
            QModelIndex idx = indexAt(event->pos());
            if (!idx.isValid()) { // && selectionModel()){
                qDebug() << selectionModel();
                if (selectionModel())
                    selectionModel()->clearSelection();
            }
        }
        QTableView::mousePressEvent(event);
    }
};

#endif // TABLEVIEW_HPP
