// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "udpstatuswidget.hpp"

#include "colorindicator.hpp"

UDPStatusWidget::UDPStatusWidget(QWidget *parent) : QWidget(parent) {

    // udp part
    mIndicator = new ColorIndicator(this);
    mIndicator->setColor(StatusColor::Grey);

    mLblDescr = new QLabel(this);
    mLblValue = new QLabel(this);
    QHBoxLayout *layout = new QHBoxLayout(this);

    layout->addWidget(mIndicator, 0, Qt::AlignLeft);
    layout->addWidget(mLblDescr, 2, Qt::AlignLeft);
    layout->addWidget(mLblValue, 0, Qt::AlignRight);
    translateUI();

    reset();

    mResetTimer.setSingleShot(true);
    QObject::connect(&mResetTimer, &QTimer::timeout, this, &UDPStatusWidget::reset);
}

/// @brief Destructor.
UDPStatusWidget::~UDPStatusWidget() {}

/// @brief Translate widgets texts.
void UDPStatusWidget::translateUI() { mLblDescr->setText(tr("UDP socket")); }

/**
 * @brief Update (udp) widget from given arguments values.
 * @param valid Control flag indicating whether or not the incoming datagram have been correctly parsed by the
 * application.
 * @param size Size of the (last) incoming datagram.
 */
void UDPStatusWidget::updateStatus(bool valid, int size, qint64 elapsed) {
    mIndicator->setColor(valid ? StatusColor::Green : StatusColor::Red);
    mResetTimer.start(2000);
    return;
}

/// @brief Refresh the texts.
void UDPStatusWidget::refreshText(double blockRate, double byteRate) {
    mLblValue->setText(
        QString("~%1 Hz (%2 kB/s)").arg(blockRate, 0, 'f', (blockRate < 1.0) ? 1 : 0).arg(byteRate, 0, 'f', 0));
}

/// @brief Reset widget to display defaults.
void UDPStatusWidget::reset() {
    mIndicator->setColor(StatusColor::Grey);
    refreshText();
}
