// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "wlaninfos.hpp"
#include <guiddef.h>

/// @brief Less than operator for GUID (used for QMap algorithms)
bool operator<(const GUID &lhs, const GUID &rhs) {
#define ISLESS(f1, f2)                                                                                                         \
    if (f1 != f2)                                                                                                              \
        return (f1 < f2);
    ISLESS(lhs.Data1, rhs.Data1);
    ISLESS(lhs.Data2, rhs.Data2);
    ISLESS(lhs.Data3, rhs.Data3);
    for (int n = 0; n < 8; n++) {
        ISLESS(lhs.Data4[n], rhs.Data4[n]);
    }
#undef ISLESS
    return false;
}

/// @brief Constructor.
WlanInfos::WlanInfos() : signalStrength(-1) {}

/**
 * @brief Check whether or not two instances are equal.
 * @details
 * Two WlanInfos are equal if their profil name and SSID are stricly the same (case sensitive comparison).
 */
bool WlanInfos::operator==(const WlanInfos &other) const {
    return profileName.compare(other.profileName) == 0 && SSID.compare(other.SSID) == 0 && guid == other.guid;
}

/// @brief Check whether or not two instances are different.
bool WlanInfos::operator!=(const WlanInfos &other) const { return !(*this == other); }

/**
 * @brief Check whether or not the instance is null.
 * @details
 * The instance is assumed to be null if its SSID is empty.
 */
bool WlanInfos::isNull() const { return SSID.isEmpty(); }
