// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef CLICKABLELABEL_HPP
#define CLICKABLELABEL_HPP

#include <QDebug>
#include <QLabel>
#include <QMouseEvent>

/**
 * @brief A QLabel that emits a clicked signal.
 */
class ClickableLabel : public QLabel {
    Q_OBJECT

  public:
    explicit ClickableLabel(QWidget *parent = nullptr) : QLabel(parent) {}
    virtual ~ClickableLabel() override {}

signals:
    void clicked();

  protected:
    virtual void mouseReleaseEvent(QMouseEvent *ev) override {
        if (ev->button() == Qt::LeftButton && geometry().contains(mapToParent(ev->pos())))
            emit clicked();
    }
    virtual void enterEvent(QEvent *ev) override {
        QLabel::enterEvent(ev);
        setCursor(Qt::PointingHandCursor);
    }
    virtual void leaveEvent(QEvent *ev) override {
        QLabel::leaveEvent(ev);
        setCursor(Qt::ArrowCursor);
    }

};

#endif // CLICKABLELABEL_HPP
