// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef CSVFILEWRITER_HPP
#define CSVFILEWRITER_HPP

#include <QtCore>
#include "globals.hpp"

class CSVFileWriter : public QObject, public QRunnable {
    Q_OBJECT

  public:
    CSVFileWriter( const QString &path,const PairOfData &data,int precision=12, QObject *parent = nullptr);
    virtual ~CSVFileWriter() {}
    bool isRunning() const;
    QString outputPath() const;
    virtual void run() override;
signals:
    /// @brief Emitted when job is finished whatever the status is.
    void finished(bool aborted = false);
    /// @brief Emitted whenever progress changed.
    void progressChanged(int value);
    /// @brief Emitted whenever progress range changed.
    void progressRangeChanged(int minValue, int maxValue);
  public slots:
    void process();
    void cancel();

  private:
    QVector<QVector<double> *> mData;
    QStringList mHeaders;
    QString mPath;
    bool mCancel;
    bool mIsRunning;
    int mPrecision;
    mutable QMutex mDataMutex;
};

#endif // CSVFILEWRITER_HPP
