// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "filefittask.hpp"

FileFitTask::FileFitTask(const QString &inputPath, const QString &outputPath, FitConfig *fitConfig, int instrOffset,
                         const FitParamReuse &reuseParams, int blockStep, Decimation decimTo, bool preLoad,
                         bool logToFile, bool stripSpectras, bool asCSV)
    : QRunnable(), inputPath(inputPath), outputPath(outputPath), fitConfig(fitConfig), instrOffset(instrOffset),
      reuseParams(reuseParams), blockStep(blockStep), decimTo(decimTo), preLoad(preLoad), logToFile(logToFile),
      stripSpectras(stripSpectras),  asCSV(asCSV) {}

void FileFitTask::run() {
    ExecTimes ttimes;
    QString sth = QString("0x%1").arg((long long)QThread::currentThreadId(), 0, 16);
    bool ret = processFile(inputPath, outputPath, (*fitConfig), instrOffset, reuseParams, blockStep, decimTo, preLoad,
                           logToFile, stripSpectras, asCSV, &ttimes);
    QString msg = QString("TH#%1 ; %2 ; %3 ; %4 ; %5\n")
                      .arg(sth, QDateTime::currentDateTimeUtc().toString("yyyy.MM.ddThh:mm:ss.zzz"), inputPath,
                           (ret ? "SUCCESS" : "FAILED"), QString::fromStdString(ttimes.toString(Units::SEC)));
    printString(msg);
}
