// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#ifndef FIT_HPP
#define FIT_HPP

#include <QtCore>

#include "isp/isp.hpp"

using namespace ISP;

void printString(const QString &string);

enum class Decimation {
    No = -1,        ///< No decimation, keep the original number of points.
    To_512 = 512,   ///< Decimate to 512 if possible.
    To_1024 = 1024, ///< Decimate to 1024 if possible.
};

/**
 * @brief Fit parameters reusability control flags.
 */
class FitParamReuse {
  public:
    FitParamReuse(bool concentration = false, bool baseLine = false, bool sigmaScale = false)
        : concentration(concentration), baseLine(baseLine), sigmaScale(sigmaScale) {}
    bool atLeast() const { return concentration || baseLine || sigmaScale; }

    bool concentration; ///< Reuse last valid fit concentration values as first guess.
    bool baseLine;      ///< Reuse last valid fit base-line coefficient values as first guess.
    bool sigmaScale;    ///< Reuse last valid fit sigma scale coefficient values as first guess.
};

bool processFile(const QString &inputPath, const QString &outputPath, const FitConfig &fitConfig, int instrOffset = 1000,
                 const FitParamReuse &reuseParams = {false, false, false}, int blockStep = 1,
                 Decimation decimTo = Decimation::No, bool preLoad = true, bool logToFile = false,
                 bool stripSpectras = false, bool asCSV = false, ExecTimes *times = nullptr);

#endif // FIT_HPP
