// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "signalappender.hpp"

/**
 * \class SignalAppender
 *
 * \brief SignalAppender is a simple appender that emits log record it receives from the logger.
 *
 * SignalAppender uses "[%{type:-7}] %{message}\n" as a default output format. It is similar to the
 * AbstractStringAppender but doesn't show a timestamp.
 *
 * Each time a record is received from the logger, the class formats and send the message with the associated log level
 * using SignalAppender::logMessage signal.
 */

SignalAppender::SignalAppender(QObject *parent) : QObject(parent), AbstractStringAppender() {}

//! Format and emits the log record.
/**
 * \sa AbstractStringAppender::format()
 */
void SignalAppender::append(const QDateTime &timeStamp, Logger::LogLevel logLevel, const char *file, int line,
                            const char *function, const QString &category, const QString &message) {
    emit logMessage(formattedString(timeStamp, logLevel, file, line, function, category, message), static_cast<int>(logLevel));
}
