// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2018

/**
 * @file logwidget.h
 * @brief Log widget declarations file
 * @author J. Burgalat
 * @date 2016-2018
 */

#ifndef LOGWIDGET_H
#define LOGWIDGET_H

#include <QWidget>

#include "logwidget_global.h"
#include "signalappender.hpp"

class QToolBar;
class QTextBrowser;
class QStringList;
class QAction;

struct Log {
    Logger::LogLevel level;
    QString message;
    Log(Logger::LogLevel level, QString message) : level(level), message(message) {}
};

class LOGWIDGETSHARED_EXPORT LogWidget : public QWidget {
    Q_OBJECT
  public:
    LogWidget(SignalAppender *appender, const QString &settingsKey = QString(), QWidget *parent = Q_NULLPTR);
    virtual ~LogWidget() Q_DECL_OVERRIDE;
    virtual QSize sizeHint() const Q_DECL_OVERRIDE;
    void translateUI();
    void loadUI();
    void saveUI();
    void setToolBarVisible(bool visible);
    QAction *toggleViewAction();

    QPointer<SignalAppender> appender();
  signals:
    void visibilityChanged(bool visible);

  public slots:
    void setAppender(SignalAppender *appender);
    void clearLog();
    void saveLog();

  private slots:
    void toggleError_p(bool enabled);
    void toggleWarning_p(bool enabled);
    void toggleInfo_p(bool enabled);
    void toggleDebug_p(bool enabled);

  protected:
    virtual void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
    virtual void hideEvent(QHideEvent *event) Q_DECL_OVERRIDE;
    virtual void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;

  private:
    QString mSettingsKey;
    QTextBrowser *logBox;
    QToolBar *toolBar;
    QAction *mToggleViewAction;
    QAction *mSaveAction;
    QAction *mClearAction;
    QAction *mShowErrorAction;
    QAction *mShowWarningAction;
    QAction *mShowInfoAction;
    QAction *mShowDebugAction;
    QVector<Log> mLogList;
    QPointer<SignalAppender> mAppender;
    void refresh();
    int mFilterFlag;

  private slots:
    void append(const QString &message, int level);
};

#endif // LOGWIDGET_H
