// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024
#ifndef MENUSECTION_HPP
#define MENUSECTION_HPP

#include <QWidgetAction>
#include <QFrame>
#include <QHBoxLayout>
#include <QLabel>
/**
 * @brief Class hack to display menu section.
 * @details
 * This class is a hack used to add section in QMenu (as it seems broken on Windows).
 * It is a simple label surrounded by two sunken QFrames.
 *
 * The method setText is overloaded in order to modify the text of the label dynamically.
 */
class MenuSection : public QWidgetAction {
    Q_OBJECT
  public:
    ///! @brief Constructor.
    MenuSection(const QString &title, QObject *parent = nullptr) : QWidgetAction(parent) {
        QWidget *container = new QWidget();
        mTitle = new QLabel(container);
        setText(title);
        QFrame *line = new QFrame(container);
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);
        line->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        QHBoxLayout *layout = new QHBoxLayout(container);
        layout->addWidget(line);
        layout->addWidget(mTitle);

        line = new QFrame(container);
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);
        line->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        layout->addWidget(line);
        layout->setContentsMargins(4, 4, 4, 4);
        setDefaultWidget(container);
    }

    /**
     * @brief Set new title.
     * @note
     * Bold tags are automatically added to the title before the new text is set.
     */
    void setText(const QString &text) { mTitle->setText(QString("<b>%1</b>").arg(text)); }

  private:
    QLabel *mTitle; //! Title of the section.
};

#endif // MENUSECTION_HPP
