#ifndef MESSAGEHANDLER_HPP
#define MESSAGEHANDLER_HPP

#include <QAbstractMessageHandler>

/// @brief Message handler for XML validation
class MessageHandler : public QAbstractMessageHandler {
  public:
    /// @brief Constructor.
    MessageHandler() : QAbstractMessageHandler(nullptr) {}
    /// @brief Get the current status message.
    QString statusMessage() const { return mDescription; }
    /// @brief Get the current line.
    qint64 line() const { return mSourceLocation.line(); }
    /// @brief Get the current column.
    qint64 column() const { return mSourceLocation.column(); }

  protected:
    /// @brief Handle (setup) messages.
    virtual void handleMessage(QtMsgType type, const QString &description, const QUrl &identifier,
                               const QSourceLocation &sourceLocation) {
        Q_UNUSED(type);
        Q_UNUSED(identifier);

        mDescription = description;
        mSourceLocation = sourceLocation;
    }

  private:
    QString mDescription;
    QSourceLocation mSourceLocation;
};

#endif // MESSAGEHANDLER_HPP
