// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

#include "progressbar.hpp"

// Icon button.

/// @brief Constructor.
IconButton::IconButton(const QIcon &icon, QWidget *parent) : QPushButton(icon, "", parent) {
    // setMouseTracking(true);
}

/// @brief Update internal mouse position  control flag when cursor enters in the widget.
void IconButton::enterEvent(QEvent *) { mIsMouseOver = true; }
/// @brief Update internal mouse position  control flag when cursor leaves the widget.
void IconButton::leaveEvent(QEvent *) { mIsMouseOver = false; }

/**
 * @brief Pit the widget.
 * @param event Paint event.
 */
void IconButton::paintEvent(QPaintEvent *event) {
    if (!icon().isNull()) {
        QStyleOptionButton option;
        initStyleOption(&option);
        option.text = QString("");
        if (mIsMouseOver == true) {
            option.icon = icon().pixmap(iconSize(), QIcon::Active);
        } else {
            option.icon = icon().pixmap(iconSize(), QIcon::Disabled);
        }
        QPainter painter(this);
        style()->drawControl(QStyle::CE_PushButton, &option, &painter, this);
        // event->ignore ();
    } else
        QPushButton::paintEvent(event);
}

// Progress bar.

/// @brief Constructor.
ProgressBar::ProgressBar(QWidget *parent) : QWidget(parent) {
    // setMouseTracking(true);
    mProgressBar = new QProgressBar(this);
    mBtnCancel = new IconButton(QIcon::fromTheme("abort"), this);
    mProgressBar->setFixedHeight(24);
    mBtnCancel->setFixedSize(24, 24);
    QHBoxLayout *layout = new QHBoxLayout(this);
    layout->setSpacing(0);
    layout->setContentsMargins(2, 2, 2, 2);
    layout->addWidget(mProgressBar, 2);
    layout->addWidget(mBtnCancel, 0, Qt::AlignLeft);
}

/// @brief Get the internal QPushButton.
IconButton *ProgressBar::button() { return mBtnCancel; }

/// @brief Get the internal QProgressBar.
QProgressBar *ProgressBar::progressBar() { return mProgressBar; }

// Status bar.

/// @brief Constructor.
StatusProgressBar::StatusProgressBar(QWidget *parent) : QStatusBar(parent) {
    // setMouseTracking(true);
    mProgressBar = new ProgressBar;
    addPermanentWidget(mProgressBar);
}

/// @brief Get the internal ProgressBar instance pointer.
ProgressBar *StatusProgressBar::progressBar() { return mProgressBar; }
