// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024

/**
 * @file validators.hpp
 * @brief floating point value validators classes declarations file.
 * @author J. Burgalat
 * @date 2016-2018
 */

#ifndef VALIDATORS_HPP
#define VALIDATORS_HPP

#include <QRegularExpression>
#include <QValidator>

class DoubleValidator : public QValidator {
  public:
    static const QRegularExpression mRe;
    DoubleValidator(QObject *parent = nullptr, bool allowEmpty = false, bool allowNaN = true);
    virtual State validate(QString &input, int &pos) const override;
    bool validateDouble(const QString &str) const;
    bool emptyAllowed() const;
    bool nanAllowed() const;

  private:
    bool mEmptyAllowed;
    bool mNaNAllowed;
};

class LogPatternValidator : public QValidator {
  public:
    static const QRegularExpression mReForbidden;
    LogPatternValidator(QObject *parent = nullptr);
    virtual State validate(QString &input, int &pos) const override;
    // virtual void fixup(QString &input) const override;
    bool validatePattern(const QString &str) const;
};

#endif // VALIDATORS_HPP
