// Copyright (c) URCA-CNRS-TOTALENERGIES - All Rights Reserved
// Authors: J. Burgalat
// 2016-2024
#ifndef MULTIFILELOADER_HPP
#define MULTIFILELOADER_HPP

#include <QtCore>

class AMDataset;

/// @brief Load files into dataset.
class MultiFileLoader : public QObject, public QRunnable {
    Q_OBJECT
  public:
    MultiFileLoader(const QVector<QStringList> &files, QObject *parent = nullptr);
    virtual ~MultiFileLoader();
    bool canceled() const;
    bool isRunning() const;
    virtual void run() override;
  signals:
    /**
     * @brief Emitted whenever a new dataset is available.
     * @param dataset Pointer to the dataset.
     * @details
     * The pointer is not owned by this MultiFileLoader. It user responsibility to delete it if needed.
     */
    void datasetLoaded(AMDataset *dataset);
    /// @brief Emitted when job is finished whatever the status is.
    void finished(bool aborted = false);
    /// @brief Emitted whenever the total progress range changes.
    void progressRangeChanged(int min, int max);
    /// @brief Emitted whenever progress changed.
    void progressChanged(int value);
    /// @brief Emitted whenever a message is sent by the loader.
    void message(const QString msg);
  public slots:
    void process();
    void cancel();

  private:
    mutable QMutex mDataMutex;
    bool mIsRunning;
    bool mCancel;
    int mNumTasks;
    QVector<QStringList> mFilesToLoad;
};

#endif // MULTIFILELOADER_HPP
