# -*- coding: utf-8 -*-
#
# ADMin v2 documentation build configuration file
import sys
import os
import os.path

import glob
import sphinx

# General information about the project.
project = u'ADMin'
copyright = u'2020-2024, Jérémie Burgalat'
# Short version
version = '2.3'
# Full version, including alpha/beta/rc tags.
release = '2.3.0'


script_dir = os.path.dirname(__file__)
videos_dir = os.path.abspath(os.path.join(script_dir,"videos"))
videos = glob.glob(os.path.join(videos_dir,"*.mp4"))



# -------------------------------------------------------------------------
# ------ internal configuration -------------------------------------------
# -------------------------------------------------------------------------

# -- General configuration ------------------------------------------------
needs_sphinx = '1.3'
templates_path = ['_templates']
source_suffix = '.rst'
master_doc = 'index'
pygments_style = 'default'
extensions = [
    'sphinx.ext.ifconfig',
]

# include the special command rst file.
#rst_prolog = "\n.. include:: .special.rst\n"

# -- Options for HTML output ----------------------------------------------
html_theme = 'sphinx_rtd_theme'

# theme options
html_theme_options = {
    'logo_only': False,
    'display_version': True,
    'prev_next_buttons_location': 'None',
    'style_external_links': True,
    # Toc options
    'collapse_navigation': True,
    'sticky_navigation': True,
    'navigation_depth': 3,
    'includehidden': False,
    'titles_only': False,
    }
html_context = {
    'show_sphinx': False,
    'show_copyright': False,
     }


html_static_path = ['_static',] + videos
html_css_files = ['style.css','video-js.min.css']
html_extra_path = ["images/credits.png"]
html_show_sourcelink = False

# -- Latex ----------------------------------------------------------------

latex_engine = 'xelatex'

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    'papersize': 'a4paper',
    'releasename':" ",
    'figure_align':'htbp',
    # The font size ('10pt', '11pt' or '12pt').
    'pointsize': '11pt',

#     'fontpkg': r'''
# \setmainfont{DejaVu Serif}
# \setsansfont{DejaVu Sans}
# \setmonofont{DejaVu Sans Mono}
# ''',

    # Additional stuff for the LaTeX preamble.
    #
    'preamble': r'''
\setcounter{secnumdepth}{0}
\setcounter{tocdepth}{1}

\usepackage{amsmath,amsfonts,amssymb,amsthm}
\usepackage{graphicx}
\usepackage[section,above]{placeins}
\usepackage[notlot,nottoc,notlof]{}
\usepackage{color}
\usepackage{transparent}
\usepackage{footnotebackref}
\usepackage{tikz}
\usepackage{tikzpagenodes}
\usepackage{datetime}
\usepackage{setspace}
\usepackage{tabularx}
\usepackage{titlesec}
\usepackage{fancyhdr}
\usepackage{enumitem}

\singlespacing

\titleformat{\chapter}[display]
  {\normalfont\Huge \scshape}{\titlerule}{-28pt}{\thechapter\ \ \Huge}[\vspace{-2pt}\titlerule]
\titleformat{name=\chapter,numberless}[display]
  {\normalfont\Huge \scshape}{\titlerule}{-28pt}{\Huge}[\vspace{-2pt}\titlerule]
\titlespacing*{\chapter}{0pt}{0pt}{*2}

\newdateformat{MonthYearFormat}{%
    \monthname[\THEMONTH], \THEYEAR}

\newdateformat{todayFormat}{%

    \monthname[\THEMONTH], \THEYEAR}

% header/footer

\pagestyle{fancy}
\fancyhf{}
\fancyfoot[CO, CE]{\thepage}

\renewcommand{\headrulewidth}{0.5pt}
\renewcommand{\footrulewidth}{0.5pt}

\definecolor{darkgreen}{rgb}{0.0, 0.2, 0.13}
\definecolor{magenta}{rgb}{1.0, 0.0, 1.0}
\definecolor{red}{rgb}{1.0, 0.0, 0.0}

''',

    'maketitle': r'''
\pagenumbering{Roman} %%% to avoid page 1 conflict with actual page 1

\begin{titlepage}

\begin{tikzpicture}[remember picture,overlay]
  \node [anchor=north west,inner sep=0] at (current page header area.east)
  {
    \hspace{-4cm}
    \includegraphics[height=1cm]{credits.png}
  };
\end{tikzpicture}

\begin{center}

  \vspace*{15mm}

  \textbf{\Huge {AUSEA}}

  \vspace{5mm}

  {\LARGE {Airborne Ultra-light Spectrometer for Environmental Applications \& exploitation}}

  \vspace{10mm}

\end{center}

\FloatBarrier

\ddmmyyyydate

\begin{table}[H]
  \renewcommand{\arraystretch}{1.5}
  \begin{tabularx}{.95\textwidth}{|l|X|}
    \hline
    Contract reference     & CRNS 147724        \\ \hline
    Document reference     & AUSEA11022019      \\ \hline
    Document type          & Application manual \\ \hline
    Document author(s)     & Jérémie Burgalat   \\ \hline
    Creation date          & 31/03/2021         \\ \hline
    Last modification date & \today             \\ \hline
  \end{tabularx}
  \renewcommand{\arraystretch}{1.0}
\end{table}

{\LARGE Changelog}

\input{changelog.txt}

\clearpage
\centering

\vspace*{40mm} %%% * is used to give space from top
\textbf{\Huge {ADMin v2}}

\vspace{20mm}
\Large \textbf{{Jérémie Burgalat}}

\vspace{10mm}
\small Created on : April, 2021

\vspace*{0mm}
\small  Last updated : \MonthYearFormat\today

\vfill

\end{titlepage}

\setlist{nosep}

\clearpage
\tableofcontents
\clearpage
\pagenumbering{arabic}
''',
    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
    'sphinxsetup': 'hmargin={0.7in,0.7in}, vmargin={0.7in,0.7in}, verbatimwithframe=true, TitleColor={rgb}{0,0,0}, HeaderFamily=\\rmfamily\\bfseries, InnerLinkColor={rgb}{0,0,1}, OuterLinkColor={rgb}{0,0,1}',

    'tableofcontents':' ',
}

latex_show_urls = 'footnote'
latex_additional_files = ["../images/credits.png","changelog.txt"]

